@@ -5,6 +5,7 @@ extern const _Bool cmbd_with_scalapack;
 extern const int cmbd_version_major;
 extern const int cmbd_version_minor;
 extern const int cmbd_version_patch;
+extern const char cmbd_version_suffix[30];
 
 struct geom_t* cmbd_init_geom(
     int n_atoms,
@@ -45,6 +46,8 @@ struct cmbd_damping* cmbd_init_damping(
 
 void cmbd_destroy_damping(struct cmbd_damping* damping);
 
+void cmbd_print_timing(struct geom_t* geom);
+
 struct result_t* cmbd_ts_energy(
     struct geom_t* geom,
     double* alpha_0,
